fix typos
diff --git a/src/main/java/org/apache/sling/rewriter/impl/components/XHtmlSerializerFactory.java b/src/main/java/org/apache/sling/rewriter/impl/components/XHtmlSerializerFactory.java
index 761096a..b66efa5 100644
--- a/src/main/java/org/apache/sling/rewriter/impl/components/XHtmlSerializerFactory.java
+++ b/src/main/java/org/apache/sling/rewriter/impl/components/XHtmlSerializerFactory.java
@@ -45,7 +45,7 @@
     }
 
     /**
-     * <p>A pedantinc XHTML serializer encoding all recognized entities with their
+     * <p>A pedantic XHTML serializer encoding all recognized entities with their
      * proper HTML names.</p>
      *
      * <p>For configuration options of this serializer, please look at the
diff --git a/src/main/java/org/apache/sling/rewriter/Processor.java b/src/main/java/org/apache/sling/rewriter/Processor.java
index fd87925..860bb03 100644
--- a/src/main/java/org/apache/sling/rewriter/Processor.java
+++ b/src/main/java/org/apache/sling/rewriter/Processor.java
@@ -50,8 +50,8 @@
 
     /**
      * Clean up the processor.
      * This method should always be called after a processor run, regardless if it was successfull or failed.
      * @param errorOccured Indicates if an error occured during processing
      */
-    void finished(boolean errorOccured) throws IOException;
+    void finished(boolean errorOccurred) throws IOException;
 }
@@ -50,8 +50,8 @@
     /**
      * Clean up the processor.
-     * This method should always be called after a processor run, regardless if it was successfull or failed.
-     * @param errorOccured Indicates if an error occured during processing
+     * This method should always be called after a processor run, regardless if it was successful or failed.
+     * @param errorOccurred Indicates if an error occurred during processing
      */